from setuptools import setup

setup(
    name='symcodelib',
    version='0.1',
    description='This library is built to get stock codes in a format required while using SmartApi websocket',
    author='Abhirath Dubey',
    author_email='abhirathdubey2804@gmail.com',
    packages=['symcodelib'],
    install_requires=['requests']
)